@@ -11,8 +11,10 @@ import seaborn as sns
 from sklearn.cluster import KMeans
 import matplotlib.pyplot as plt
 
+import lc_reconstruction_analysis.utils as utils
 
-def get_roi_map(DATA_DIR, rois=None):
+
+def get_roi_map(DATA_DIR, roi_version=1):
     """
     Returns maps from ID to ROI, acronym, and parent
     """
@@ -36,24 +38,7 @@ def get_roi_map(DATA_DIR, rois=None):
     ].to_dict()
     id_to_parent[None] = None  # to account for out of bands points
     # Create pathing dictionaries to group children CCF levels
-    if rois is None:
-        rois = [
-            "CB",
-            "MY",
-            "P",
-            "MB",
-            "TH",
-            "HY",
-            "CNU",
-            "CTXsp",
-            "HPF",
-            "OLF",
-            "Isocortex",
-            "fiber tracts",
-            "VS",
-            "grv",
-            "retina",
-        ]  # remove "fiber tracts","VS","grv","retina" later
+    rois = utils.get_roi_list(roi_version)
     roiIDs = [acronym_to_id[roi] for roi in rois]
     # Get the pathing for each leaf node, find which roi each belongs to
     id_to_path = ccf_structures.set_index("id")["structure_id_path"].to_dict()
