@@ -409,11 +409,9 @@ def compute_mesh_centroid(vertices, indices):
         return weighted_centroid / total_area
 
 
-def get_roi_centroids(DATA_DIR, roi_version=1):
+def get_roi_list(roi_version=2):
     """
-    get a dictionary of the AP/DV position
-    of the centroids of the ROIs.
-    roi_verion determines which set of ROIs to use
+    Returns a collection of ROIs
     """
     if roi_version == 1:
         rois = [
@@ -449,6 +447,16 @@ def get_roi_centroids(DATA_DIR, roi_version=1):
             "mfbs",
             "VS",
         ]
+    return rois
+
+
+def get_roi_centroids(DATA_DIR, roi_version=2):
+    """
+    get a dictionary of the AP/DV position
+    of the centroids of the ROIs.
+    roi_verion determines which set of ROIs to use
+    """
+    rois = get_roi_list(roi_version)
 
     # Get map of structure acronyms to ccf IDs
     acronym_to_id = get_acronym_to_id(DATA_DIR)
@@ -456,6 +464,9 @@ def get_roi_centroids(DATA_DIR, roi_version=1):
     # Iterate through ROIs and get centroid for each
     centroidDict = {}
     for name in rois:
+        if name == "Other":
+            centroidDict[name] = np.array([13000, -6018])
+            continue
         x = get_mesh_from_id(acronym_to_id[name], DATA_DIR)
         centroidDict[name] = compute_mesh_centroid(x[0], x[2])[0:2]
         centroidDict[name][1] = -centroidDict[name][1]
